@@ -28,7 +28,7 @@ import ts.tester.util.*;
  * <code>CheckResult</code>NX̋@\NXB
  *
  * @author  V. 
- * @version $Revision: 1.2 $, $Date: 2007/02/16 16:12:49 $
+ * @version $Revision: 1.3 $, $Date: 2007/10/08 16:11:08 $
  */
 public class CheckResultTest extends FunctionTester
 {
@@ -70,6 +70,38 @@ public class CheckResultTest extends FunctionTester
     EQUAL(ResultType.Incomplete.toString(), "Incomplete");
   }
 
+  public void setMethod()
+  {
+    MSG("ʏ̑̏ꍇB");
+
+    CheckResult r = CheckResult.OK();
+    EQUAL(r.getMethod(), "");
+    r.setMethod("");
+    EQUAL(r.getMethod(), "");
+  }
+
+  public void setMethod_1()
+  {
+    MSG("k̏ꍇ");
+
+    CheckResult r = CheckResult.NG();
+    EQUAL(r.getMethod(), "");
+    try {
+      r.setMethod(null); NG();
+    } catch (AssertionError e) {
+      OK(e.toString());
+    }
+    EQUAL(r.getMethod(), "");
+    r.setMethod("ABC");
+    EQUAL(r.getMethod(), "ABC");
+    try {
+      r.setMethod(null); NG("aaa");
+    } catch (AssertionError e) {
+      OK(e.toString());
+    }
+    EQUAL(r.getMethod(), "ABC");
+  }
+
   public void setMessage()
   {
     MSG("ʏ̑̏ꍇ");
