@@ -371,7 +371,7 @@ import java.util.HashMap;
  * </table>
  *
  * @author  V. 
- * @version $Revision: 1.3 $, $Date: 2007/06/25 16:07:41 $
+ * @version $Revision: 1.4 $, $Date: 2007/10/08 16:11:08 $
  */
 public class HtmlPrinter extends HtmlPrinterBase
   implements CoveragePrinter
@@ -554,6 +554,11 @@ public class HtmlPrinter extends HtmlPrinterBase
   {
     assert (objMap != null) : "@param:objMap is null.";
 
+    if (coverage_ == null) {
+      super.outputHtmlFile(objMap);
+      return;
+    }
+
     replacedMap_ = objMap;
   }
 
@@ -732,6 +737,10 @@ public class HtmlPrinter extends HtmlPrinterBase
     assert (arg != null) : "@param:arg is null.";
     assert (objMap != null) : "@param:objMap is null.";
 
+    if (coverage_ == null) {
+      return super.replaceArgument(arg, objMap);
+    }
+
     if (arg.startsWith(FMT_CLASS_COVERAGE)) {
       Object obj = objMap.get(FMT_CLASS_COVERAGE);
       if (obj == null || !(obj instanceof String)) {
